@@ -5,7 +5,7 @@
 /* *                                                                        * */
 /* * project   : libmng                                                     * */
 /* * file      : libmng_object_prc.h       copyright (c) 2000-2004 G.Juyn   * */
-/* * version   : 1.0.7                                                      * */
+/* * version   : 1.0.9                                                      * */
 /* *                                                                        * */
 /* * purpose   : Object processing routines (definition)                    * */
 /* *                                                                        * */
@@ -59,6 +59,9 @@
 /* *             1.0.7 - 03/24/2004 - G.R-P                                 * */
 /* *             - added more SKIPCHUNK conditionals                        * */
 /* *                                                                        * */
+/* *             1.0.9 - 12/05/2004 - G.Juyn                                * */
+/* *             - added conditional MNG_OPTIMIZE_OBJCLEANUP                * */
+/* *                                                                        * */
 /* ************************************************************************** */
 
 #if defined(__BORLANDC__) && defined(MNG_STRICT_ANSI)
@@ -176,6 +179,8 @@ mng_retcode mng_colorcorrect_object  (mng_datap  pData,
 
 mng_retcode mng_create_ani_image  (mng_datap      pData);
 
+#ifndef MNG_OPTIMIZE_CHUNKREADER
+
 mng_retcode mng_create_ani_plte   (mng_datap      pData,
                                    mng_uint32     iEntrycount,
                                    mng_palette8ep paEntries);
@@ -359,11 +364,83 @@ mng_retcode mng_create_ani_disc   (mng_datap      pData,
                                    mng_uint16p    pIds);
 #endif
 
+#else /* MNG_OPTIMIZE_CHUNKREADER */
+
+mng_retcode mng_create_ani_plte   (mng_datap      pData);
+mng_retcode mng_create_ani_trns   (mng_datap      pData);
+mng_retcode mng_create_ani_gama   (mng_datap      pData,
+                                   mng_chunkp     pChunk);
+mng_retcode mng_create_ani_chrm   (mng_datap      pData,
+                                   mng_chunkp     pChunk);
+mng_retcode mng_create_ani_srgb   (mng_datap      pData,
+                                   mng_chunkp     pChunk);
+mng_retcode mng_create_ani_iccp   (mng_datap      pData,
+                                   mng_chunkp     pChunk);
+mng_retcode mng_create_ani_bkgd   (mng_datap      pData);
+mng_retcode mng_create_ani_loop   (mng_datap      pData,
+                                   mng_chunkp     pChunk);
+mng_retcode mng_create_ani_endl   (mng_datap      pData,
+                                   mng_uint8      iLevel);
+mng_retcode mng_create_ani_defi   (mng_datap      pData);
+mng_retcode mng_create_ani_basi   (mng_datap      pData,
+                                   mng_chunkp     pChunk);
+mng_retcode mng_create_ani_clon   (mng_datap      pData,
+                                   mng_chunkp     pChunk);
+mng_retcode mng_create_ani_back   (mng_datap      pData);
+mng_retcode mng_create_ani_fram   (mng_datap      pData,
+                                   mng_chunkp     pChunk);
+mng_retcode mng_create_ani_move   (mng_datap      pData,
+                                   mng_chunkp     pChunk);
+mng_retcode mng_create_ani_clip   (mng_datap      pData,
+                                   mng_chunkp     pChunk);
+mng_retcode mng_create_ani_show   (mng_datap      pData);
+mng_retcode mng_create_ani_term   (mng_datap      pData,
+                                   mng_chunkp     pChunk);
+#ifndef MNG_SKIPCHUNK_SAVE
+mng_retcode mng_create_ani_save   (mng_datap      pData);
+#endif
+#ifndef MNG_SKIPCHUNK_SEEK
+mng_retcode mng_create_ani_seek   (mng_datap      pData,
+                                   mng_chunkp     pChunk);
+#endif
+#ifndef MNG_NO_DELTA_PNG
+mng_retcode mng_create_ani_dhdr   (mng_datap      pData,
+                                   mng_chunkp     pChunk);
+mng_retcode mng_create_ani_prom   (mng_datap      pData,
+                                   mng_chunkp     pChunk);
+mng_retcode mng_create_ani_ipng   (mng_datap      pData);
+mng_retcode mng_create_ani_ijng   (mng_datap      pData);
+
+mng_retcode mng_create_ani_pplt   (mng_datap      pData,
+                                   mng_uint8      iType,
+                                   mng_uint32     iCount,
+                                   mng_palette8ep paIndexentries,
+                                   mng_uint8p     paAlphaentries,
+                                   mng_uint8p     paUsedentries);
+#endif
+
+#ifndef MNG_SKIPCHUNK_MAGN
+mng_retcode mng_create_ani_magn   (mng_datap      pData,
+                                   mng_chunkp     pChunk);
+#endif
+#ifndef MNG_SKIPCHUNK_PAST
+mng_retcode mng_create_ani_past   (mng_datap      pData,
+                                   mng_chunkp     pChunk);
+#endif
+#ifndef MNG_SKIPCHUNK_DISC
+mng_retcode mng_create_ani_disc   (mng_datap      pData,
+                                   mng_chunkp     pChunk);
+#endif
+
+#endif /* MNG_OPTIMIZE_CHUNKREADER */
+
 /* ************************************************************************** */
 
 mng_retcode mng_free_ani_image    (mng_datap    pData,
                                    mng_objectp  pObject);
 
+#ifndef MNG_OPTIMIZE_OBJCLEANUP
+
 mng_retcode mng_free_ani_plte     (mng_datap    pData,
                                    mng_objectp  pObject);
 mng_retcode mng_free_ani_trns     (mng_datap    pData,
@@ -378,17 +455,11 @@ mng_retcode mng_free_ani_chrm     (mng_datap    pData,
 mng_retcode mng_free_ani_srgb     (mng_datap    pData,
                                    mng_objectp  pObject);
 #endif
-#ifndef MNG_SKIPCHUNK_iCCP
-mng_retcode mng_free_ani_iccp     (mng_datap    pData,
-                                   mng_objectp  pObject);
-#endif
 #ifndef MNG_SKIPCHUNK_bKGD
 mng_retcode mng_free_ani_bkgd     (mng_datap    pData,
                                    mng_objectp  pObject);
 #endif
 #ifndef MNG_SKIPCHUNK_LOOP
-mng_retcode mng_free_ani_loop     (mng_datap    pData,
-                                   mng_objectp  pObject);
 mng_retcode mng_free_ani_endl     (mng_datap    pData,
                                    mng_objectp  pObject);
 #endif
@@ -414,10 +485,6 @@ mng_retcode mng_free_ani_term     (mng_datap    pData,
 mng_retcode mng_free_ani_save     (mng_datap    pData,
                                    mng_objectp  pObject);
 #endif
-#ifndef MNG_SKIPCHUNK_SAVE
-mng_retcode mng_free_ani_seek     (mng_datap    pData,
-                                   mng_objectp  pObject);
-#endif
 #ifndef MNG_NO_DELTA_PNG
 mng_retcode mng_free_ani_dhdr     (mng_datap    pData,
                                    mng_objectp  pObject);
@@ -434,6 +501,22 @@ mng_retcode mng_free_ani_pplt     (mng_datap    pData,
 mng_retcode mng_free_ani_magn     (mng_datap    pData,
                                    mng_objectp  pObject);
 #endif
+
+#endif /* MNG_OPTIMIZE_OBJCLEANUP */
+
+
+#ifndef MNG_SKIPCHUNK_iCCP
+mng_retcode mng_free_ani_iccp     (mng_datap    pData,
+                                   mng_objectp  pObject);
+#endif
+#ifndef MNG_SKIPCHUNK_LOOP
+mng_retcode mng_free_ani_loop     (mng_datap    pData,
+                                   mng_objectp  pObject);
+#endif
+#ifndef MNG_SKIPCHUNK_SAVE
+mng_retcode mng_free_ani_seek     (mng_datap    pData,
+                                   mng_objectp  pObject);
+#endif
 #ifndef MNG_SKIPCHUNK_PAST
 mng_retcode mng_free_ani_past     (mng_datap    pData,
                                    mng_objectp  pObject);
@@ -524,6 +607,7 @@ mng_retcode mng_process_ani_disc  (mng_datap    pData,
 /* ************************************************************************** */
 
 #ifdef MNG_SUPPORT_DYNAMICMNG
+#ifndef MNG_OPTIMIZE_CHUNKREADER
 mng_retcode mng_create_event      (mng_datap    pData,
                                    mng_uint8    iEventtype,
                                    mng_uint8    iMasktype,
@@ -535,10 +619,12 @@ mng_retcode mng_create_event      (mng_datap    pData,
                                    mng_uint8    iIndex,
                                    mng_uint32   iSegmentnamesize,
                                    mng_pchar    zSegmentname);
-
+#else
+mng_retcode mng_create_event      (mng_datap    pData,
+                                   mng_ptr      pEntry);
+#endif
 mng_retcode mng_free_event        (mng_datap    pData,
                                    mng_objectp  pObject);
-
 mng_retcode mng_process_event     (mng_datap    pData,
                                    mng_objectp  pObject);
 #endif
